@@ -11,6 +11,8 @@ from aanalytics2 import config, token_provider
 class AdobeRequest:
     """
     Handle request to Audience Manager and taking care that the request have a valid token set each time.
+    Attributes:
+        restTime : Time to rest before sending new request when reaching too many request status code.
     """
 
     def __init__(self,
@@ -32,6 +34,7 @@ class AdobeRequest:
                 'You have to upload the configuration file with importConfigFile method.')
         self.config = deepcopy(config_object)
         self.header = deepcopy(header)
+        self.restTime = 30
         self.retry = retry
         if self.config['token'] == '' or time.time() > self.config['date_limit']:
             token_and_expiry = token_provider.get_token_and_expiry_for_config(config=self.config, verbose=verbose)
@@ -58,7 +61,7 @@ class AdobeRequest:
         """
         Abstraction for getting data
         """
-        internRetry = self.retry - kwargs.get("retry", 0)
+        internRetry = kwargs.get("retry",  self.retry)
         self._checkingDate()
         if headers is None:
             headers = self.header
@@ -77,22 +80,21 @@ class AdobeRequest:
             print(f"request URL : {res.request.url}")
             print(f"statut_code : {res.status_code}")
         try:
-            if res.status_code == 429 and internRetry > 0:
+            while str(res.status_code) == "429":
                 if kwargs.get("verbose", False):
-                    print(f'Too many requests: {internRetry} retry left')
-                time.sleep(45)
-                res_json = self.getData(endpoint, params=params, data=data, headers=headers, retry=1, **kwargs)
-                return res_json
+                    print(f'Too many requests: retrying in {self.restTime} seconds')
+                time.sleep(self.restTime)
+                res = requests.get(endpoint, headers=headers, params=params, data=data)
             res_json = res.json()
         except:
             res_json = {'error': 'Request Error'}
-            if internRetry > 0:
+            while internRetry > 0:
                 if kwargs.get("verbose", False):
                     print('Retry parameter activated')
                     print(f'{internRetry} retry left')
                 if 'error' in res_json.keys():
                     time.sleep(30)
-                    res_json = self.getData(endpoint, params=params, data=data, headers=headers, retry=1, **kwargs)
+                    res_json = self.getData(endpoint, params=params, data=data, headers=headers, retry=internRetry-1, **kwargs)
                     return res_json
         return res_json
 
